@@ -10,7 +10,7 @@
 open Lwt
 open LTerm_widget
 
-lwt () =
+let main () =
   let waiter, wakener = wait () in
 
   let vbox = new vbox in
@@ -55,5 +55,10 @@ lwt () =
   let frame = new frame in
   frame#set vbox;
 
-  lwt term = Lazy.force LTerm.stdout in
-  run term frame waiter
+  Lazy.force LTerm.stdout >>= fun term ->
+  LTerm.enable_mouse term >>= fun () ->
+  Lwt.finalize 
+    (fun () -> run term frame waiter)
+    (fun () -> LTerm.disable_mouse term)
+
+let () = Lwt_main.run (main ())
